#!/usr/bin/env node

import { spawn } from 'child_process';
import fs from 'fs';
import { Command } from 'commander';
import { highlightLine } from '../lib/parser.js';
import chalk from 'chalk';

// Configurar CLI con commander
const program = new Command();
program
  .argument('<cmd...>', 'Comando a ejecutar')
  .option('--filter <word>', 'Muestra solo líneas que contengan esta palabra')
  .option('--export <file>', 'Exporta la salida filtrada a un archivo')
  .parse();

const options = program.opts();
const args = program.args;

// Ejecutar el comando
const child = spawn(args.join(' '), { shell: true });

// Función con colapsado de stack traces + filtros
function formatWithCollapse(lines, options = {}) {
  let stackBuffer = [];
  let inStack = false;
  const output = [];

  lines.forEach((line) => {
    if (options.filter && !line.toLowerCase().includes(options.filter.toLowerCase())) return;

    if (/^\s*at\s/.test(line)) {
      stackBuffer.push(line);
      inStack = true;
    } else {
      if (inStack && stackBuffer.length > 3) {
        output.push(chalk.gray(`[📦 Stack trace de ${stackBuffer.length} líneas colapsado]`));
      } else {
        output.push(...stackBuffer.map(l => chalk.dim(l)));
      }
      stackBuffer = [];
      inStack = false;
      output.push(highlightLine(line));
    }
  });

  if (stackBuffer.length) {
    if (stackBuffer.length > 3) {
      output.push(chalk.gray(`[📦 Stack trace de ${stackBuffer.length} líneas colapsado]`));
    } else {
      output.push(...stackBuffer.map(l => chalk.dim(l)));
    }
  }

  return output;
}

// Leer y mostrar la salida
child.stdout.on('data', (data) => {
  const lines = data.toString().split('\n');
  const formatted = formatWithCollapse(lines, options);
  formatted.forEach(line => console.log(line));
  if (options.export) fs.appendFileSync(options.export, formatted.join('\n') + '\n');
});

child.stderr.on('data', (data) => {
  const lines = data.toString().split('\n');
  const formatted = formatWithCollapse(lines, options);
  formatted.forEach(line => console.log(line));
  if (options.export) fs.appendFileSync(options.export, formatted.join('\n') + '\n');
});