import chalk from 'chalk';

export function highlightLine(line) {
  if (/^\s*at\s/.test(line)) return chalk.dim(line); // Stack trace
  if (/Caused by:/i.test(line)) return chalk.redBright.bold('💥 ' + line);
  if (/ECONNREFUSED|ECONNRESET|ENOTFOUND/i.test(line)) return chalk.red.bold('🚫 ' + line);
  if (/GET|POST|PUT|DELETE/i.test(line)) return chalk.magentaBright('➡️  ' + line);
  if (/statusCode|404|500|503|403/.test(line)) return chalk.bgRed.white.bold('🔻 ' + line);
  if (/ERROR|Exception|fail/i.test(line)) return chalk.red.bold('❌ ' + line);
  if (/WARN/i.test(line)) return chalk.yellow('⚠️ ' + line);
  if (/INFO/i.test(line)) return chalk.blue('ℹ️ ' + line);
  if (/DEBUG/i.test(line)) return chalk.gray('🐞 ' + line);
  if (/https?:\/\//.test(line)) return chalk.underline.cyan(line); // Resalta links
  if (/localhost:\d+/.test(line)) return chalk.cyanBright(line); // Resalta puertos locales

  try {
    const parsed = JSON.parse(line);
    return chalk.greenBright(JSON.stringify(parsed, null, 2));
  } catch {
    return line;
  }
}